@@ -14,14 +14,16 @@ class Service(Generic[GenWorker]):
                              *args,
                              trigger: BaseTrigger = None,
                              on_error_callback: TaskErrorCallback = None,
-                             add_job_kw: Dict = None, **kwargs):
+                             add_job_kw: Dict = None, return_event: bool = False, **kwargs,
+                             ):
         await self.emmit_event(
             TaskIMessage(task,
                          trigger,
                          on_error_callback=on_error_callback,
                          add_job_kw=add_job_kw,
                          args=args,
-                         kwargs=kwargs))
+                         kwargs=kwargs,
+                         return_event=return_event))
 
     async def wait_for_response(self, msg: IMessage):
         return await self.worker.channel.produce_for_response(msg)
