@@ -19,6 +19,7 @@ from apscheduler.job import Job
 from apscheduler.jobstores.memory import MemoryJobStore
 from apscheduler.schedulers.background import BackgroundScheduler
 from apscheduler.triggers.base import BaseTrigger
+from apscheduler.triggers.interval import IntervalTrigger
 from pytz import utc
 
 from web_foundation.kernel.abstract.container import GenericDepContainer
@@ -128,12 +129,21 @@ class TaskExecutor(Worker, Generic[GenericDepContainer]):
 
     async def _task_message_handler(self, message: TaskIMessage):
         message.task = self._get_callable(message.task)
+
+        if isinstance(message.trigger, IntervalTrigger):
+            for task_id, task in self._tasks.items():
+                if task.scheduled_job.func == message.task:
+                    task.scheduled_job.trigger = message.trigger
+                    task.scheduled_trigger = message.trigger
+                    return
+
         arc_task = Task(id=str(uuid.uuid4()),
                         name=message.task.__name__,
                         status="new",
                         scheduled_trigger=message.trigger,
                         on_error_callback=message.on_error_callback,
                         return_event=message.return_event)
+
         arc_task.scheduled_job = self._scheduler.add_job(message.task,
                                                          name=arc_task.name,
                                                          id=arc_task.id,
@@ -166,9 +176,9 @@ class TaskExecutor(Worker, Generic[GenericDepContainer]):
                 task.error = event.exception
                 task.status = 'error'
                 if task.on_error_callback:
-                    asyncio.create_task(task.on_error_callback(event, task))
+                    asyncio.run(task.on_error_callback(event, task))
             elif task.return_event and event.retval:
-                self.channel.produce(event.retval)
+                asyncio.run(self.channel.produce(event.retval))
 
         self._scheduler.add_listener(_on_job_submitted, EVENT_JOB_SUBMITTED)
         self._scheduler.add_listener(_on_job_exec, EVENT_JOB_EXECUTED | EVENT_JOB_ERROR)
