@@ -58,7 +58,7 @@ class Worker(Isolate, MetricsMixin, Generic[GenericDepContainer]):
         await self._after_worker_fork()
         await self.run()
 
-    async def close(self):
+    async def close(self, *args, **kwargs):
         await self._container.shutdown_resources()
 
     @property
